# multicraft

[![PyPI](https://img.shields.io/pypi/v/multicraft)](https://pypi.org/project/multicraft/)
[![Python](https://img.shields.io/pypi/pyversions/multicraft)](https://www.python.org/downloads/)
![Downloads](https://img.shields.io/pypi/dm/multicraft)
![Status](https://img.shields.io/pypi/status/multicraft)
[![Issues](https://img.shields.io/github/issues/legopitstop/multicraft)](https://github.com/legopitstop/multicraft-py/issues)

Interact with your Minecraft server from hosts that use [Multicraft](https://www.multicraft.org/) using Python.

## Installation
Install the module with pip:
```bat
pip3 install multicraft
```
Update existing installation: `pip3 install multicraft --upgrade`

## Features
- Authed requests
- Includes a handful of common multicraft hosts.

See the docs for more information.

## Dependencies
|Name|Description|
|--|--|
|[requests](https://pypi.org/project/requests/) | Requests is a simple, yet elegant, HTTP library. |
